@@ -6,6 +6,7 @@ from pytorch_optimizer.diffgrad import DiffGrad
 from pytorch_optimizer.diffrgrad import DiffRGrad
 from pytorch_optimizer.fp16 import SafeFP16Optimizer
 from pytorch_optimizer.lamb import Lamb
+from pytorch_optimizer.lars import LARS
 from pytorch_optimizer.madgrad import MADGRAD
 from pytorch_optimizer.radam import RAdam
 from pytorch_optimizer.ralamb import RaLamb
@@ -45,6 +46,8 @@ def load_optimizers(optimizer: str, use_fp16: bool = False):
         opt = Lamb
     elif optimizer == 'ralamb':
         opt = RaLamb
+    elif optimizer == 'lars':
+        opt = LARS
     else:
         raise NotImplementedError(f'[-] not implemented optimizer : {optimizer}')
 
